@@ -5,6 +5,8 @@ use warnings;
 
 use base 'Module::Build';
 
+our $VERSION = sprintf "%d", '$Revision: 11 $ ' =~ /(\d+)/;
+
 use YAML qw(LoadFile DumpFile);
 
 sub ACTION_install {
@@ -35,11 +37,11 @@ sub ACTION_install {
   my ($mp3, $ogg);
 
   for (qw(read write)) {
-    ++$mp3 if $config->{$pkg}{"${_}_mp3"};
+    $mp3 += 50 if $config->{$pkg}{"${_}_mp3"};
   }
 
   for (qw(read write)) {
-    ++$ogg if $config->{$pkg}{"${_}_ogg"};
+    $ogg +=50 if $config->{$pkg}{"${_}_ogg"};
   }
 
   # prefer non-perl implementations
@@ -66,3 +68,34 @@ sub ACTION_install {
 }
 
 1;
+
+=head1 NAME
+
+AudioFile::Info::Build - Build utilities for AudioFile::Info.
+
+=head1 DESCRIPTION
+
+This is a module which is used as part of the build system for
+AudioFile::Info plugins.
+
+See L<AudioFile::Info> for more details.
+
+=head1 METHODS
+
+=head2 ACTION_install
+
+Overrides the ACTION_install method from Module::Build.
+
+=head1 AUTHOR
+
+Dave Cross, E<lt>dave@dave.org.ukE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2003 by Dave Cross
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=cut
+
